package
module
Version:
v1.1.3
Opens a new window with list of versions in this module.
Published: Apr 12, 2021
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
shellgo
Parse bytecode from go tool objdump output.
How to?
make
go tool compile -S -N file.go
go tool objdump -S file.o | shellgo
Flags
-dump <file_name> / Result in file_name.in and file_name.out respectively to stdin and stdout.
-version / Print out build version
-0x / Change format from packed (02) to formatted (0x00, 0x02, ).
Documentation
¶
func STDINReader() []rune
STDINReader append standard input characters.
Output keep raw which is default, unformatted bytecode.
Parse extracts bytecode from go tool objdump output.
Default return unformatted raw output.
Format0x format output adding 0x at the beginning at every code.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.